package TinyURL;

use strict;
use warnings;
use parent 'Pickles::WebApp';
our $VERSION = '0.01';

1;
__END__

=head1 NAME

TinyURL -

=head1 SYNOPSIS

  use TinyURL;

=head1 DESCRIPTION

TinyURL is

=head1 AUTHOR

Default Name E<lt>default {at} example.comE<gt>

=head1 SEE ALSO

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
