package Pickles::Response;
use strict;
use parent 'Plack::Response';

1;

__END__

=head1 NAME

Pickles::Response - A Response Object

=head1 SYNOPSIS

    use Plickles::Response;
    # see Plack::Response

=cut
