package Pickles::Request;
use strict;
use parent 'Plack::Request';


1;

__END__

=head1 NAME

Pickles::Request - A Request Object

=head1 SYNOPSIS

    use Pickles::Request;
    # See Plack::Request

=cut
